<?php

namespace Drupal\stripe_webhooks\Event;

final class CheckoutSessionEvents {

  /**
   * Occurs when a payment intent using a delayed payment method fails.
   *
   * @ Event
   *
   * @see https://stripe.com/docs/api/events/types#event_types-checkout.session.async_payment_failed
   */
  const CHECKOUT_SESSION_ASYNC_PAYMENT_FAILED = 'stripe.webhooks.checkout.session.async_payment_failed';

  /**
   * Occurs when a payment intent using a delayed payment method finally succeeds.
   *
   * @ Event
   *
   * @see https://stripe.com/docs/api/events/types#event_types-checkout.session.async_payment_succeeded
   */
  const CHECKOUT_SESSION_ASYNC_PAYMENT_SUCCEEDED = 'stripe.webhooks.checkout.session.async_payment_succeeded';


  /**
   * Occurs when a Checkout Session has been successfully completed.
   *
   * @ Event
   *
   * @see https://stripe.com/docs/api/events/types#event_types-checkout.session.completed
   */
  const CHECKOUT_SESSION_COMPLETED = 'stripe.webhooks.checkout.session.completed';



  /**
   * Occurs when a Checkout Session is expired.
   *
   * @ Event
   *
   * @see https://stripe.com/docs/api/events/types#event_types-checkout.session.expired
   */
  const CHECKOUT_SESSION_EXPIRED = 'stripe.webhooks.checkout.session.expired';
}
